// Version: 1.3.3
function extractSearchData(card) {
  const link = card.querySelector('a.chakra-link');
  if (!link || !link.href) {
    console.warn('No link found in card, using defaults');
    return { city: 'Unknown', state: 'Unknown', country: 'Unknown', checkIn: '', checkOut: '', rooms: 0, guests: 0, nights: 1 };
  }

  const url = new URL(link.href);
  const params = new URLSearchParams(url.search);

  const query = decodeURIComponent(params.get('query') || '');
  const locationParts = query.split(', ').map(part => part.trim());
  const city = locationParts[0] || 'Unknown';
  const country = locationParts[locationParts.length - 1] || 'Unknown';
  const state = locationParts.length > 2 ? locationParts[1] : 'Unknown';

  const checkIn = decodeURIComponent(params.get('checkIn') || '').replace(/%2F/g, '/');
  const checkOut = decodeURIComponent(params.get('checkOut') || '').replace(/%2F/g, '/');

  const rooms = parseInt(params.get('rooms')) || 0;
  const adults = parseInt(params.get('adults')) || 0;
  const children = parseInt(params.get('children')) || 0;
  const guests = adults + children;

  let nights = 1;
  try {
    const checkInDate = new Date(checkIn);
    const checkOutDate = new Date(checkOut);
    if (checkInDate && checkOutDate && checkOutDate > checkInDate) {
      nights = Math.ceil((checkOutDate - checkInDate) / (1000 * 60 * 60 * 24));
    }
  } catch (e) {
    console.warn('Error calculating nights:', e);
  }

  return { city, state, country, checkIn, checkOut, rooms, guests, nights };
}

async function checkVersion() {
  const currentVersion = chrome.runtime.getManifest().version;

  try {
    console.log('Fetching latest version from index.php');
    const response = await fetch('https://hotellps.com/index.php', {
      method: 'GET',
      mode: 'cors'
    });
    if (!response.ok) throw new Error('Failed to fetch version');
    const html = await response.text();
    const parser = new DOMParser();
    const doc = parser.parseFromString(html, 'text/html');
    const latestVersionElement = doc.getElementById('plugin-version');
    const latestVersion = latestVersionElement ? latestVersionElement.textContent : currentVersion;

    console.log(`Current version: ${currentVersion}, Latest version: ${latestVersion}`);

    if (currentVersion !== latestVersion) {
      const warning = document.createElement('div');
      warning.style.backgroundColor = 'pink';
      warning.style.color = 'black';
      warning.style.fontSize = '24px';
      warning.style.padding = '10px';
      warning.style.textAlign = 'center';
      warning.style.position = 'fixed';
      warning.style.top = '0';
      warning.style.left = '0';
      warning.style.width = '100%';
      warning.style.zIndex = '1000';
      warning.textContent = `Warning: You are running an outdated version (${currentVersion}) of the Hotel Points Calculator. Latest version is ${latestVersion}. Please update!`;
      document.body.insertBefore(warning, document.body.firstChild);
    }
  } catch (error) {
    console.error('Error checking version:', error);
  }
}

async function updateHotelCards() {
  const hotelCards = document.querySelectorAll('.css-13lpchn');

  const cardData = Array.from(hotelCards).map(card => {
    const searchData = extractSearchData(card);

    const pointsElement = card.querySelector('.css-jvp12g');
    const pointsText = pointsElement?.textContent.trim() || '';
    const pointsMatch = pointsText.match(/Earn ([\d,]+) miles/);
    const totalPoints = pointsMatch ? parseInt(pointsMatch[1].replace(',', '')) : null;

    const priceElement = card.querySelector('.css-1ndtlri');
    const priceText = priceElement?.textContent.trim() || '';
    const priceMatch = priceText.match(/[\d,.]+/);
    const price = priceMatch ? parseFloat(priceMatch[0].replace(',', '')) : null;

    const pointsPerDollar = (price && totalPoints && price > 0 && searchData.nights > 0) 
      ? (totalPoints / price / searchData.nights).toFixed(2) 
      : null;

    const hotelName = card.querySelector('.css-48nr6r')?.textContent.trim() || 'Unknown';

    return {
      card,
      pointsElement,
      pointsPerDollar,
      totalPoints,
      hotelName,
      city: searchData.city,
      state: searchData.state,
      country: searchData.country,
      checkIn: searchData.checkIn,
      checkOut: searchData.checkOut,
      rooms: searchData.rooms,
      guests: searchData.guests,
      price,
      nights: searchData.nights
    };
  }).filter(data => data.pointsPerDollar !== null);

  if (cardData.length === 0) return;

  const pointsPerDollarValues = cardData.map(data => parseFloat(data.pointsPerDollar));
  const bestValue = Math.max(...pointsPerDollarValues);
  const worstValue = Math.min(...pointsPerDollarValues);

  cardData.forEach(({ card, pointsElement, pointsPerDollar }) => {
    let highlight = card.querySelector('.points-per-dollar');
    if (!highlight) {
      highlight = document.createElement('span');
      highlight.className = 'points-per-dollar';
      highlight.style.padding = '2px 5px';
      highlight.style.marginLeft = '5px';
      highlight.style.fontWeight = 'bold';
      pointsElement.appendChild(highlight);
    }
    highlight.textContent = `${pointsPerDollar} pts/$/night`;
    highlight.style.backgroundColor =
      parseFloat(pointsPerDollar) === bestValue ? 'lightgreen' :
      parseFloat(pointsPerDollar) === worstValue ? 'pink' : 'yellow';
  });

  try {
    console.log('Attempting fetch to save_hotel_data.php');
    const response = await fetch('https://hotellps.com/save_hotel_data.php', {
      method: 'POST',
      headers: { 'Content-Type': 'application/json' },
      body: JSON.stringify(cardData.map(data => ({
        hotel_name: data.hotelName || '',
        city: data.city || '',
        state: data.state || '',
        country: data.country || '',
        check_in: data.checkIn || '',
        check_out: data.checkOut || '',
        rooms: data.rooms ?? 0,
        guests: data.guests ?? 0,
        points_per_dollar: data.pointsPerDollar ?? '0.00',
        price_per_night: data.price ?? 0.00,
        total_points: data.totalPoints ?? 0
      })))
    });
    console.log('Fetch response status:', response.status);
    console.log('Fetch response:', await response.text());
    if (!response.ok) throw new Error(`Server error: ${response.status} ${response.statusText}`);
    console.log('Data sent successfully');
  } catch (error) {
    console.error('Error sending data:', error);
  }
}

checkVersion();
updateHotelCards();

const observer = new MutationObserver(() => {
  updateHotelCards();
});
observer.observe(document.body, { childList: true, subtree: true });

setInterval(updateHotelCards, 5000);